Module colors

Module colors 

Base color types, gradients and layered paints.

Structs

Color
RGBA color used by default Cotis configs and commands.
ColorPos
Position for gradient control points.
GradientStop
A color and its position along a gradient axis (typically 0.0–1.0).
LayeredColor
Stack of paints drawn in order.
LinearGradient
Linear gradient along the line from start to end in normalized coordinates (0–1).
RadialGradient
Radial gradient centered at center with the given radius in normalized coordinates.
RoundedRectGradient
Rounded rectangle gradient in normalized coordinates (0-1).

Enums

ColorAttachmentPoint
Attachment point used by gradient positioning.
ColorLayer
One layer in a LayeredColor: a solid color or a gradient.