pub enum AxisSizing {
Fit(f32, f32),
Grow(f32, f32),
Fixed(f32),
Percent(f32),
InnerPercent(f32),
}Expand description
Sizing modes for one axis.
Variants
Fit(f32, f32)
Fits the element’s width/height within a min and max constraint.
Grow(f32, f32)
Expands the element to fill available space within min/max constraints.
Fixed(f32)
Sets a fixed width/height.
Percent(f32)
Sets width/height as a percentage of its parent. Value should be between 0.0 and Inf.
InnerPercent(f32)
Sets width/height as a percentage of its parent minus its padding. Value should be between 0.0 and 1.0.