Base color types, gradients and layered paints.
Structs
- Color
- RGBA color used by default Cotis configs and commands.
- Color
Pos - Position for gradient control points.
- Gradient
Stop - A color and its position along a gradient axis (typically 0.0–1.0).
- Layered
Color - Stack of paints drawn in order.
- Linear
Gradient - Linear gradient along the line from
starttoendin normalized coordinates (0–1). - Radial
Gradient - Radial gradient centered at
centerwith the givenradiusin normalized coordinates. - Rounded
Rect Gradient - Rounded rectangle gradient in normalized coordinates (0-1).
Enums
- Color
Attachment Point - Attachment point used by gradient positioning.
- Color
Layer - One layer in a
LayeredColor: a solid color or a gradient.