pub struct RichTextElementBuilder<'a> { /* private fields */ }Expand description
Builder for RichTextElementConfig.
Implementations
Sourceimpl<'a> RichTextElementBuilder<'a>
impl<'a> RichTextElementBuilder<'a>
Sourcepub fn new(
text: OwnedOrRef<'a, str>,
default_config: TextConfigStylePair,
) -> Self
pub fn new( text: OwnedOrRef<'a, str>, default_config: TextConfigStylePair, ) -> Self
Creates a new builder with the provided text and default style/config.
Sourcepub fn add_config(&mut self, config: TextConfigStylePair) -> usize
pub fn add_config(&mut self, config: TextConfigStylePair) -> usize
Adds an override config and returns an index intended for configure_range.
Sourcepub fn configure_range(&mut self, range: Range<usize>, config_index: usize)
pub fn configure_range(&mut self, range: Range<usize>, config_index: usize)
Applies an override config to a text range.
Panics
Panics if range.end is outside the text length or config_index is not
valid for the current override set.
Sourcepub fn into_config(self) -> RichTextElementConfig<'a>
pub fn into_config(self) -> RichTextElementConfig<'a>
Finalizes the builder into a RichTextElementConfig.