Render command structs consumed by renderer integrations.
Modules
- render_
t_ list - Typed heterogeneous command-list helpers. Typed heterogeneous render-command lists.
Structs
- Border
- Represents a border with a specified color, width, and corner radii.
- Border
Width - Defines the border width for each side of an element.
- ClipEnd
- Ends the most recent active clip region.
- Clip
Start - Represents a clip element with corner radii, clipping axis and position.
- Corner
Radii - Defines individual corner radii for an element.
- Image
- Represents an image with defined dimensions and data.
- Rectangle
- Fill command for rounded rectangles. Represents a rectangle with a specified color and corner radii.
- Render
Command Info - Shared command metadata available on every render command.
- Text
- Represents a text element with styling attributes.